Usage
get_stopclusters(
max_distance = 350,
file = "stop_clusters.xlsx",
rp_database = Sys.getenv("RP_DATABASE"),
rp_odbc_name = Sys.getenv("RP_ODBC_NAME"),
TZ = "America/New_York"
)Arguments
- max_distance
Maximum distance between stops in a cluster, in meters.
- file
Name of excel file to save report to
- rp_database
Name of the RP database to connect to. Retrieved from
RP_DATABASEenvironment variable by default but can be overridden here, see RVersatransRP package for details.- rp_odbc_name
Name of the Windows ODBC data source to use. Retrieved from
RP_ODBC_NAMEenvironment variable by default but can be overridden here, see RVersatransRP package for details.- TZ
The timezone used by the database server.
Value
data.frame with columns:
- StopPointID
intThe point iD of the Stop- CustomDescription
chrThe stop description- VisibleRouteID
chrThe route number- Longitude
dblStop Longitude- Stop_Latitude
dblStop Latitude- ProgramDescription
chrStop type- cluster
chrStop cluster ID- clusterSize
intNumber of stops in the cluster